<assetcontinuous>
    <link type="text/css" rel="stylesheet" href="assets/styles/modal.css">
    <style>
        .main {
            margin: 0 auto;
            justify-content: center;
            padding: 20px 150px 5px 150px;
        }
        label {
            width: 70px;
        }
        .alert {
            padding: 10px !important;
            margin-bottom: 0px !important;
        }
        #label-manual {
            margin-left: 30px;
        }
    </style>
    <div id="continuousModal" class="modal fade" role="dialog">
        <div class="modal-dialog">
            <!-- Modal content-->
            <div class="modal-content">
                <div class="modal-header">
                    <div id="title">端末連続登録</div>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span>&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <div class="alert alert-danger" if="{errorMessage}">{errorMessage}</div>
                    <div class="main">
                        <div class="form-group">
                            <label>機種</label>
                            <select id="kindType" class="select" />
                        </div>
                        <div class="form-group">
                            <label>端末ID</label>
                            <input id="assetId" type="text" name="assetId" onkeydown="{checkAssetId}"/>
                        </div>
                        <div class="form-group required">
                            <label>IMEI</label>
                            <input id="imei" type="text" name="imei" onkeydown="{checkIMEI}"/>
                        </div>
                        <div class="form-group required">
                            <label>SIMID</label>
                            <input id="simId" type="text" name="simId" onkeydown="{checkSimId}"/>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <div id="btn-group" class="btn-gr pull-right">
                        <button onclick="{ onCloseClick }" class="bdt-button buttons-create btn btn-nc">閉じる</button>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <complete/>
    <script>
        export default {
            onBeforeMount(props, state) {
                this.assetService = props.assetService
                this.codeService = props.codeService
            },
            async onMounted() {
                const codeResp = await this.codeService.get('soracom')
                if (codeResp.statusCode != 200 || !codeResp.data || !codeResp.data.length) {
                    return
                }
                const codes = codeResp.data.filter(code => {
                    return code.key != 'group_id'
                })
                const data = []
                codes.forEach(code => {
                    data.push({
                        id: code.value,
                        text: code.key
                    })
                })
                $('select.select').css('width', '180px').select2({data})
            },
            show() {
                $('#continuousModal').modal()
            },
            checkAssetId(e) {
                if (e.keyCode != 13) return
                $('#imei').focus()
            },
            checkIMEI(e) {
                this.clearMessage()
                // Enterキー以外は処理しない
                if (e.keyCode != 13) return

                var value = e.currentTarget.value
                if (!value) {
                    this.errorMessage = 'IMEIを入力してください'
                    this.update()
                    return
                }
                if (!CheckUtil.checkNumber(value)) {
                    this.errorMessage = '数字を入力してください'
                    this.update()
                    return
                }
                $('#simId').focus()
            },
            async checkSimId(e) {
                this.clearMessage()
                // Enterキー以外は処理しない
                if (e.keyCode != 13) return

                var assetId = $('#assetId').val()
                if (assetId && !CheckUtil.checkAlphabetNumber(assetId)) {
                    this.errorMessage = '端末IDは半角英数字を入力してください'
                    this.update()
                    return
                }
                if (assetId) {
                    // 端末ID重複チェック
                    var resp = await this.assetService.get(assetId)
                    if (resp.message) {
                        toastr.error(resp.message)
                        return
                    }
                    if (resp.data.length > 0) {
                        this.errorMessage = '入力された端末IDは使用されています'
                        this.update()
                        return
                    }
                }

                var imei = $('#imei').val()
                if (!imei) {
                    this.errorMessage = 'IMEIを入力してください'
                    this.update()
                    return
                }
                if (!CheckUtil.checkNumber(imei)) {
                    this.errorMessage = 'IMEIは数字を入力してください'
                    this.update()
                    return
                }

                var simId = $('#simId').val()
                if (!simId) {
                    this.errorMessage = 'SIMIDを入力してください'
                    this.update()
                    return
                }
                if (!CheckUtil.checkNumber(simId)) {
                    this.errorMessage = '数字を入力してください'
                    this.update()
                    return
                }

                // 登録処理
                const kindType = $('#kindType').val()
                var response = await this.assetService.continuousRegistration(kindType, assetId, imei, simId, UserInfo.getInstance().getEmail())
                if (response.statusCode != 200) {
                    toastr.error(response.message)
                    return
                }
                assetId = response.data.assetId
                var password = response.data.password

                // 入力内容をクリアする
                $('#assetId').val('')
                $('#imei').val('')
                $('#simId').val('')
                $('#imei').focus()

                setTimeout(function () {
                    $('#asset_datatables').dataTable().api().ajax.reload()
                }, 3000)

                // メッセージ表示
                riot.unmount('complete',{},'assetcontinuouscomplete')
                var complete = riot.mount('complete',{
                    assetId: assetId,
                    password: password
                }, 'assetcontinuouscomplete')[0]

                complete.show()

            },
            onCloseClick() {
                $('#continuousModal').modal('hide')
            },
            clearMessage() {
                this.errorMessage = null
                this.update()
            },
            onInputTypeChange(e) {
                var value = e.currentTarget.value
                localStorage.setItem('inputType', value)

                // 手動
                if (value == 0) {
                    $('#assetId').prop('disabled', false)
                    $('#assetId').focus()
                    return
                }

                $('#assetId').prop('disabled', true)
                $('#imei').focus()
            }
        }
    </script>
</assetcontinuous>
